@@ -9,6 +9,7 @@ use Dir::Self qw(:static);
 use Config;
 use File::Path qw(mkpath rmtree);
 use Getopt::Long;
+use Archive::Extract;
 
 GetOptions(
     "build-prefix=s" => \my $BuildPrefix,
@@ -63,7 +64,8 @@ sub lib_2_tarball {
 
 sub tarball_2_dir {
     my $tarball = shift;
-    runcmd("tar xzf $tarball");
+    my $ae = Archive::Extract->new(archive => $tarball);
+    $ae->extract();    
     my $filename = fileparse($tarball, qr/\.tar\..*/);
     return $filename;
 }
@@ -73,7 +75,6 @@ sub tarball_2_dir {
 ### Tarball Names                                                            ###
 ################################################################################
 ################################################################################
-my $LIBVBUCKET_TARBALL = lib_2_tarball('libvbucket');
 my $LIBCOUCHBASE_TARBALL = lib_2_tarball('libcouchbase');
 my $LIBEVENT_TARBALL = lib_2_tarball('libevent');
 
@@ -137,19 +138,6 @@ sub lib_is_built {
     return 0;
 }
 
-################################################################################
-### ISASL                                                                    ###
-################################################################################
-#my $LIBISASL_TARBALL = lib_2_tarball('libisasl');
-#disabled because we now bundle it with libcouchbase itself.
-#if(should_build('ISASL')) {
-#    chdir $TOPLEVEL;
-#    chdir tarball_2_dir($LIBISASL_TARBALL);
-#    runcmd("./configure", @COMMON_OPTIONS) unless -e 'Makefile';
-#    log_info("Configuring libisasl");
-#    runcmd("$MAKEPROG install");
-#    log_info("Installed libisasl");
-#}
 
 ################################################################################
 ### libevent                                                                 ###
@@ -168,29 +156,6 @@ if(should_build('EVENT')) {
     runcmd("$MAKEPROG install");
 }
 
-
-################################################################################
-### libvbucket                                                               ###
-################################################################################
-# if(should_build('VBUCKET'))
-{
-    chdir $TOPLEVEL;
-    chdir tarball_2_dir($LIBVBUCKET_TARBALL);
-    if(!-e 'Makefile') {
-        runcmd("./configure", @COMMON_OPTIONS);
-        log_info("Configured libvbucket");
-    }
-
-    runcmd("$MAKEPROG");
-    log_info("build libvbucket");
-    runcmd("$MAKEPROG install");
-    log_info("installed libvbucket");
-    runcmd("$MAKEPROG check") if $RUN_TESTS;
-    log_info("tested libvbucket");
-}
-
-
-
 ################################################################################
 ### libcouchbase                                                             ###
 ################################################################################
@@ -201,8 +166,6 @@ if(should_build('EVENT')) {
 
     my @libcouchbase_options = (
         @COMMON_OPTIONS,
-        "--disable-tools",
-        "--enable-embed-libevent-plugin",
     );
 
     if($^O =~ /solaris/) {
@@ -222,26 +185,6 @@ if(should_build('EVENT')) {
         push @libcouchbase_options, '--disable-couchbasemock';
     }
 
-    #First, we need to mangle the 'configure' script:
-    {
-        my @conflines;
-        open my $confh, "+<", "configure" or die "opening configure: $!";
-        @conflines = <$confh>;
-        foreach my $line (@conflines) {
-            if($line =~ s/LIBS=(-l\S+)/LIBS="\$LIBS $1"/msg) {
-                print STDERR ">> REPLACING: $line";
-            }
-            if($line =~ s/sasl_server_init\(NULL,/sasl_client_init\(/) {
-                print STDERR ">> REPLACING: $line";
-            }
-        }
-        seek($confh, 0, 0);
-        print $confh @conflines;
-        truncate($confh, tell($confh));
-
-        close($confh);
-    }
-
     runcmd("./configure", @libcouchbase_options) unless -e 'Makefile';
     runcmd("$MAKEPROG install");
     runcmd("$MAKEPROG check -s") if $RUN_TESTS;
