@@ -1,29 +1,36 @@
 #include "perl-couchbase.h"
 
-void plcb_ctor_cbc_opts(
-    AV *options, char **hostp, char **userp, char **passp, char **bucketp)
+void plcb_ctor_cbc_opts(AV *options,
+                        char **hostp,
+                        char **userp,
+                        char **passp,
+                        char **bucketp)
 {
     
 #define _assign_options(dst, opt_idx, defl) \
-if( (tmp = av_fetch(options, opt_idx, 0)) && SvTRUE(*tmp) ) { \
-    *dst = SvPV_nolen(*tmp); \
-} else { \
-    *dst = defl; \
-}
+    if ( (tmp = av_fetch(options, opt_idx, 0)) && SvTRUE(*tmp) ) { \
+        *dst = SvPV_nolen(*tmp); \
+    } else { \
+        *dst = defl; \
+    }
+
     SV **tmp;
     
     _assign_options(hostp, PLCB_CTORIDX_SERVERS, "127.0.0.1:8091");
     _assign_options(userp, PLCB_CTORIDX_USERNAME, NULL);
     _assign_options(passp, PLCB_CTORIDX_PASSWORD, NULL);
     _assign_options(bucketp, PLCB_CTORIDX_BUCKET, "default");
+
 #undef _assign_options
 }
 
 static void ctor_extract_methpairs(AV *options,
-                                   int idx, SV **outmeth, SV **inmeth)
+                                   int idx,
+                                   SV **outmeth,
+                                   SV **inmeth)
 {
     SV **tmpsv;
-    AV *methav;
+    AV *methav = NULL;
     int ii;
     
     SV **assgn_array[] = { outmeth, inmeth };
@@ -41,9 +48,11 @@ static void ctor_extract_methpairs(AV *options,
     
     for (ii = 0; ii < 2; ii++) {
         tmpsv = av_fetch(methav, ii, 0);
-        if(SvROK(*tmpsv) == 0 || SvTYPE(SvRV(*tmpsv)) != SVt_PVCV) {
+
+        if (SvROK(*tmpsv) == 0 || SvTYPE(SvRV(*tmpsv)) != SVt_PVCV) {
             die("Expected code reference.");
         }
+
         *(assgn_array[ii]) = newRV_inc(SvRV(*tmpsv));
     }
 }
@@ -51,8 +60,6 @@ static void ctor_extract_methpairs(AV *options,
 void plcb_ctor_conversion_opts(PLCB_t *object, AV *options)
 {
     SV **tmpsv;
-    AV *methav;
-    int dummy;
     
 #define meth_assert_getpairs(flag, optidx) \
     ((object->my_flags & flag) \
@@ -64,15 +71,24 @@ void plcb_ctor_conversion_opts(PLCB_t *object, AV *options)
     : NULL)
     
 #define meth_assert_assign(target_field, source_idx, diemsg) \
-    if((tmpsv = av_fetch(methav, source_idx, 0)) == NULL) { \
+    if ((tmpsv = av_fetch(methav, source_idx, 0)) == NULL) { \
         die("Nothing in IDX=%d (%s)", source_idx, diemsg); \
     } \
-    if(! ((SvROK(*tmpsv) && SvTYPE(SvRV(*tmpsv)) == SVt_PVCV) ) ) { \
+    if (! ((SvROK(*tmpsv) && SvTYPE(SvRV(*tmpsv)) == SVt_PVCV) ) ) { \
         die("Expected CODE reference at IDX=%d: %s",source_idx, diemsg); \
     } \
     object->target_field = newRV_inc(SvRV(*tmpsv));
     
-    if( (tmpsv = av_fetch(options, PLCB_CTORIDX_MYFLAGS, 0))
+#define meth_maybe_assign(idx, target, name) \
+    if ( (tmpsv = av_fetch(options, idx, 0)) != NULL && SvTYPE(*tmpsv) != SVt_NULL) { \
+        if (!SvROK(*tmpsv) || SvTYPE(SvRV(*tmpsv)) != SVt_PVCV) { \
+            die("Expected a code reference for %s but found something else", name); \
+        } \
+        (void)SvREFCNT_inc(*tmpsv); \
+        object->target = *tmpsv; \
+    }
+
+    if ( (tmpsv = av_fetch(options, PLCB_CTORIDX_MYFLAGS, 0))
        && SvIOK(*tmpsv)) {
         object->my_flags = SvUV(*tmpsv);
     }
@@ -99,38 +115,60 @@ void plcb_ctor_conversion_opts(PLCB_t *object, AV *options)
     if ((tmpsv = av_fetch(options, PLCB_CTORIDX_COMP_THRESHOLD, 0))
        && SvIOK(*tmpsv)) {
         object->compress_threshold = SvIV(*tmpsv);
+
     } else {
         object->compress_threshold = 0;
     }
+
+    /* For Couch/JSON */
+    meth_maybe_assign(PLCB_CTORIDX_JSON_ENCODE_METHOD,
+                      couch.cv_json_encode,
+                      "JSON encode");
+
+    meth_maybe_assign(PLCB_CTORIDX_JSON_VERIFY_METHOD,
+                      couch.cv_json_verify,
+                      "JSON verify");
 }
 
-void plcb_ctor_init_common(PLCB_t *object, libcouchbase_t instance,
-                           AV *options)
+void plcb_ctor_init_common(PLCB_t *object, lcb_t instance, AV *options)
 {
     NV timeout_value;
     SV **tmpsv;
     
     object->instance = instance;
     object->errors = newAV();
-    if(! (object->ret_stash = gv_stashpv(PLCB_RET_CLASSNAME, 0)) ) {
-        die("Could not load '%s'", PLCB_RET_CLASSNAME);
+
+#define get_stash_assert(stashname, target) \
+    if (! (object->target = gv_stashpv(stashname, 0)) ) { \
+        die("Couldn't load '%s'", stashname); \
     }
     
+    get_stash_assert(PLCB_RET_CLASSNAME, ret_stash);
+    get_stash_assert(PLCB_ITER_CLASSNAME, iter_stash);
+    get_stash_assert(PLCB_COUCH_HANDLE_INFO_CLASSNAME, couch.handle_av_stash);
+
+#undef get_stash_assert
+
     /*gather instance-related options from the constructor*/
-    if( (tmpsv = av_fetch(options, PLCB_CTORIDX_TIMEOUT, 0))  && 
+    if ( (tmpsv = av_fetch(options, PLCB_CTORIDX_TIMEOUT, 0))  &&
             (SvIOK(*tmpsv) || SvNOK(*tmpsv))) {
         timeout_value = SvNV(*tmpsv);
-        if(!timeout_value) {
+
+        if (!timeout_value) {
             warn("Cannot use 0 for timeout");
+
         } else {
-            libcouchbase_set_timeout(instance,
+            lcb_set_timeout(instance,
                 timeout_value * (1000*1000));
         }
     }
     
-    if((tmpsv = av_fetch(options, PLCB_CTORIDX_NO_CONNECT, 0)) &&
+    if ((tmpsv = av_fetch(options, PLCB_CTORIDX_NO_CONNECT, 0)) &&
        SvTRUE(*tmpsv)) {
         object->my_flags |= PLCBf_NO_CONNECT;
     }
     /*maybe more stuff here?*/
+    object->sync.type = PLCB_SYNCTYPE_SINGLE;
+
+    plcb_couch_callbacks_setup(object);
 }
